summaryrefslogtreecommitdiff
path: root/hscript/script_l.hh
diff options
context:
space:
mode:
Diffstat (limited to 'hscript/script_l.hh')
-rw-r--r--hscript/script_l.hh8
1 files changed, 4 insertions, 4 deletions
diff --git a/hscript/script_l.hh b/hscript/script_l.hh
index 1f048c6..e1becc8 100644
--- a/hscript/script_l.hh
+++ b/hscript/script_l.hh
@@ -23,11 +23,11 @@ struct ScriptLocation {
std::string name;
/*! The line number of the current location. */
int line;
- /*! Whether this script is nested or the original script. */
- bool nested;
+ /*! Whether this script is inherited or the original script. */
+ bool inherited;
- ScriptLocation(std::string _n, int _l, bool _nest = false) :
- name{_n}, line{_l}, nested{_nest} {};
+ ScriptLocation(std::string _n, int _l, bool _inherit = false) :
+ name{_n}, line{_l}, inherited{_inherit} {};
};
}